package com.mysql.jdbc;

import java.io.IOException;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.InetAddress;
import java.net.Socket;
import java.net.SocketException;
import java.util.Properties;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/StandardSocketFactory.class */
public class StandardSocketFactory implements SocketFactory {
    public static final String TCP_NO_DELAY_PROPERTY_NAME = "tcpNoDelay";
    public static final String TCP_KEEP_ALIVE_DEFAULT_VALUE = "true";
    public static final String TCP_KEEP_ALIVE_PROPERTY_NAME = "tcpKeepAlive";
    public static final String TCP_RCV_BUF_PROPERTY_NAME = "tcpRcvBuf";
    public static final String TCP_SND_BUF_PROPERTY_NAME = "tcpSndBuf";
    public static final String TCP_TRAFFIC_CLASS_PROPERTY_NAME = "tcpTrafficClass";
    public static final String TCP_RCV_BUF_DEFAULT_VALUE = "0";
    public static final String TCP_SND_BUF_DEFAULT_VALUE = "0";
    public static final String TCP_TRAFFIC_CLASS_DEFAULT_VALUE = "0";
    public static final String TCP_NO_DELAY_DEFAULT_VALUE = "true";
    private static Method setTraficClassMethod;
    protected String host = null;
    protected int port = 3306;
    protected Socket rawSocket = null;
    static Class class$java$net$Socket;
    static Class class$java$net$InetAddress;

    static Class class$(String x0) {
        try {
            return Class.forName(x0);
        } catch (ClassNotFoundException x1) {
            throw new NoClassDefFoundError(x1.getMessage());
        }
    }

    static {
        Class cls;
        try {
            if (class$java$net$Socket == null) {
                cls = class$("java.net.Socket");
                class$java$net$Socket = cls;
            } else {
                cls = class$java$net$Socket;
            }
            setTraficClassMethod = cls.getMethod("setTrafficClass", Integer.TYPE);
        } catch (NoSuchMethodException e) {
            setTraficClassMethod = null;
        } catch (SecurityException e2) {
            setTraficClassMethod = null;
        }
    }

    @Override // com.mysql.jdbc.SocketFactory
    public Socket afterHandshake() throws SocketException, IOException {
        return this.rawSocket;
    }

    @Override // com.mysql.jdbc.SocketFactory
    public Socket beforeHandshake() throws SocketException, IOException {
        return this.rawSocket;
    }

    private void configureSocket(Socket sock, Properties props) throws SocketException, IOException {
        try {
            sock.setTcpNoDelay(Boolean.valueOf(props.getProperty(TCP_NO_DELAY_PROPERTY_NAME, "true")).booleanValue());
            String keepAlive = props.getProperty(TCP_KEEP_ALIVE_PROPERTY_NAME, "true");
            if (keepAlive != null && keepAlive.length() > 0) {
                sock.setKeepAlive(Boolean.valueOf(keepAlive).booleanValue());
            }
            int receiveBufferSize = Integer.parseInt(props.getProperty(TCP_RCV_BUF_PROPERTY_NAME, "0"));
            if (receiveBufferSize > 0) {
                sock.setReceiveBufferSize(receiveBufferSize);
            }
            int sendBufferSize = Integer.parseInt(props.getProperty(TCP_SND_BUF_PROPERTY_NAME, "0"));
            if (sendBufferSize > 0) {
                sock.setSendBufferSize(sendBufferSize);
            }
            int trafficClass = Integer.parseInt(props.getProperty(TCP_TRAFFIC_CLASS_PROPERTY_NAME, "0"));
            if (trafficClass > 0 && setTraficClassMethod != null) {
                setTraficClassMethod.invoke(sock, new Integer(trafficClass));
            }
        } catch (Throwable t) {
            unwrapExceptionToProperClassAndThrowIt(t);
        }
    }

    @Override // com.mysql.jdbc.SocketFactory
    public Socket connect(String hostname, int portNumber, Properties props) throws SocketException, IOException {
        Class cls;
        Class cls2;
        Class<?> cls3;
        if (props != null) {
            this.host = hostname;
            this.port = portNumber;
            Method connectWithTimeoutMethod = null;
            Method socketBindMethod = null;
            String localSocketHostname = props.getProperty("localSocketAddress");
            String connectTimeoutStr = props.getProperty("connectTimeout");
            int connectTimeout = 0;
            boolean wantsTimeout = (connectTimeoutStr == null || connectTimeoutStr.length() <= 0 || connectTimeoutStr.equals("0")) ? false : true;
            boolean wantsLocalBind = localSocketHostname != null && localSocketHostname.length() > 0;
            boolean needsConfigurationBeforeConnect = socketNeedsConfigurationBeforeConnect(props);
            if (wantsTimeout || wantsLocalBind || needsConfigurationBeforeConnect) {
                if (connectTimeoutStr != null) {
                    try {
                        connectTimeout = Integer.parseInt(connectTimeoutStr);
                    } catch (NumberFormatException e) {
                        throw new SocketException(new StringBuffer().append("Illegal value '").append(connectTimeoutStr).append("' for connectTimeout").toString());
                    }
                }
                try {
                    Class socketAddressClass = Class.forName("java.net.SocketAddress");
                    if (class$java$net$Socket == null) {
                        cls = class$("java.net.Socket");
                        class$java$net$Socket = cls;
                    } else {
                        cls = class$java$net$Socket;
                    }
                    connectWithTimeoutMethod = cls.getMethod("connect", socketAddressClass, Integer.TYPE);
                    if (class$java$net$Socket == null) {
                        cls2 = class$("java.net.Socket");
                        class$java$net$Socket = cls2;
                    } else {
                        cls2 = class$java$net$Socket;
                    }
                    socketBindMethod = cls2.getMethod("bind", socketAddressClass);
                } catch (NoClassDefFoundError e2) {
                } catch (NoSuchMethodException e3) {
                } catch (Throwable th) {
                }
                if (wantsLocalBind && socketBindMethod == null) {
                    throw new SocketException("Can't specify \"localSocketAddress\" on JVMs older than 1.4");
                }
                if (wantsTimeout && connectWithTimeoutMethod == null) {
                    throw new SocketException("Can't specify \"connectTimeout\" on JVMs older than 1.4");
                }
            }
            if (this.host != null) {
                if (!wantsLocalBind && !wantsTimeout && !needsConfigurationBeforeConnect) {
                    Throwable caughtWhileConnecting = null;
                    for (InetAddress inetAddress : InetAddress.getAllByName(this.host)) {
                        try {
                            this.rawSocket = new Socket(inetAddress, this.port);
                            configureSocket(this.rawSocket, props);
                            break;
                        } catch (Exception ex) {
                            caughtWhileConnecting = ex;
                        }
                    }
                    if (this.rawSocket == null) {
                        unwrapExceptionToProperClassAndThrowIt(caughtWhileConnecting);
                    }
                } else {
                    try {
                        InetAddress[] possibleAddresses = InetAddress.getAllByName(this.host);
                        Throwable caughtWhileConnecting2 = null;
                        Object localSockAddr = null;
                        Constructor addrConstructor = null;
                        try {
                            Class inetSocketAddressClass = Class.forName("java.net.InetSocketAddress");
                            Class<?>[] clsArr = new Class[2];
                            if (class$java$net$InetAddress == null) {
                                cls3 = class$("java.net.InetAddress");
                                class$java$net$InetAddress = cls3;
                            } else {
                                cls3 = class$java$net$InetAddress;
                            }
                            clsArr[0] = cls3;
                            clsArr[1] = Integer.TYPE;
                            addrConstructor = inetSocketAddressClass.getConstructor(clsArr);
                            if (wantsLocalBind) {
                                localSockAddr = addrConstructor.newInstance(InetAddress.getByName(localSocketHostname), new Integer(0));
                            }
                        } catch (Throwable ex2) {
                            unwrapExceptionToProperClassAndThrowIt(ex2);
                        }
                        for (InetAddress inetAddress2 : possibleAddresses) {
                            try {
                                this.rawSocket = new Socket();
                                configureSocket(this.rawSocket, props);
                                Object sockAddr = addrConstructor.newInstance(inetAddress2, new Integer(this.port));
                                socketBindMethod.invoke(this.rawSocket, localSockAddr);
                                connectWithTimeoutMethod.invoke(this.rawSocket, sockAddr, new Integer(connectTimeout));
                                break;
                            } catch (Exception ex3) {
                                this.rawSocket = null;
                                caughtWhileConnecting2 = ex3;
                            }
                        }
                        if (this.rawSocket == null) {
                            unwrapExceptionToProperClassAndThrowIt(caughtWhileConnecting2);
                        }
                    } catch (Throwable t) {
                        unwrapExceptionToProperClassAndThrowIt(t);
                    }
                }
                return this.rawSocket;
            }
        }
        throw new SocketException("Unable to create socket");
    }

    private boolean socketNeedsConfigurationBeforeConnect(Properties props) {
        int receiveBufferSize = Integer.parseInt(props.getProperty(TCP_RCV_BUF_PROPERTY_NAME, "0"));
        if (receiveBufferSize > 0) {
            return true;
        }
        int sendBufferSize = Integer.parseInt(props.getProperty(TCP_SND_BUF_PROPERTY_NAME, "0"));
        if (sendBufferSize > 0) {
            return true;
        }
        int trafficClass = Integer.parseInt(props.getProperty(TCP_TRAFFIC_CLASS_PROPERTY_NAME, "0"));
        if (trafficClass > 0 && setTraficClassMethod != null) {
            return true;
        }
        return false;
    }

    private void unwrapExceptionToProperClassAndThrowIt(Throwable caughtWhileConnecting) throws SocketException, IOException {
        if (caughtWhileConnecting instanceof InvocationTargetException) {
            caughtWhileConnecting = ((InvocationTargetException) caughtWhileConnecting).getTargetException();
        }
        if (caughtWhileConnecting instanceof SocketException) {
            throw ((SocketException) caughtWhileConnecting);
        }
        if (caughtWhileConnecting instanceof IOException) {
            throw ((IOException) caughtWhileConnecting);
        }
        throw new SocketException(caughtWhileConnecting.toString());
    }
}
